developerscripttools.DeveloperScript
====================================

.. inheritance-diagram:: abjad.tools.developerscripttools.DeveloperScript.DeveloperScript.DeveloperScript
   :private-bases:

.. autoclass:: abjad.tools.developerscripttools.DeveloperScript.DeveloperScript.DeveloperScript

Read-only Properties
--------------------

.. autoattribute:: abjad.tools.developerscripttools.DeveloperScript.DeveloperScript.DeveloperScript.alias

.. autoattribute:: abjad.tools.developerscripttools.DeveloperScript.DeveloperScript.DeveloperScript.argument_parser

.. autoattribute:: abjad.tools.developerscripttools.DeveloperScript.DeveloperScript.DeveloperScript.formatted_help

.. autoattribute:: abjad.tools.developerscripttools.DeveloperScript.DeveloperScript.DeveloperScript.formatted_usage

.. autoattribute:: abjad.tools.developerscripttools.DeveloperScript.DeveloperScript.DeveloperScript.formatted_version

.. autoattribute:: abjad.tools.developerscripttools.DeveloperScript.DeveloperScript.DeveloperScript.long_description

.. autoattribute:: abjad.tools.developerscripttools.DeveloperScript.DeveloperScript.DeveloperScript.program_name

.. autoattribute:: abjad.tools.developerscripttools.DeveloperScript.DeveloperScript.DeveloperScript.scripting_group

.. autoattribute:: abjad.tools.developerscripttools.DeveloperScript.DeveloperScript.DeveloperScript.short_description

.. autoattribute:: abjad.tools.developerscripttools.DeveloperScript.DeveloperScript.DeveloperScript.storage_format

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. autoattribute:: abjad.tools.developerscripttools.DeveloperScript.DeveloperScript.DeveloperScript.version

Methods
-------

.. automethod:: abjad.tools.developerscripttools.DeveloperScript.DeveloperScript.DeveloperScript.process_args

.. automethod:: abjad.tools.developerscripttools.DeveloperScript.DeveloperScript.DeveloperScript.setup_argument_parser

Special Methods
---------------

.. automethod:: abjad.tools.developerscripttools.DeveloperScript.DeveloperScript.DeveloperScript.__call__

.. automethod:: abjad.tools.developerscripttools.DeveloperScript.DeveloperScript.DeveloperScript.__eq__

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.developerscripttools.DeveloperScript.DeveloperScript.DeveloperScript.__ge__

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.developerscripttools.DeveloperScript.DeveloperScript.DeveloperScript.__gt__

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.developerscripttools.DeveloperScript.DeveloperScript.DeveloperScript.__le__

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.developerscripttools.DeveloperScript.DeveloperScript.DeveloperScript.__lt__

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.developerscripttools.DeveloperScript.DeveloperScript.DeveloperScript.__ne__

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.developerscripttools.DeveloperScript.DeveloperScript.DeveloperScript.__repr__

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`
